@@ -1,8 +1,9 @@
+from builtins import range, object
 import os
 import paramiko
 import string
 
-class GeneralUtils():
+class GeneralUtils(object):
     '''
 
     This Class very generic util functions.
